@@ -17,19 +17,23 @@ The [lfs](https://github.com/Canop/lfs) application is a viewer for lfs-core and
 
 */
 
+mod block_device;
 mod device_id;
 mod disk;
 mod error;
+mod label;
 mod mount;
 mod mountinfo;
 mod stats;
 mod sys;
 
 pub use {
-    device_id::DeviceId,
-    disk::{read_disks, Disk},
-    error::{Error, Result},
+    block_device::{BlockDevice, BlockDeviceList},
+    device_id::*,
+    disk::Disk,
+    error::*,
+    label::{read_labels, Labelling},
     mount::{read_mounts, Mount},
-    mountinfo::{read_mountinfo, MountId, MountInfo},
+    mountinfo::*,
     stats::Stats,
 };
